# 关键字模式
此处的behavior模式是指在测试用例中使用关键字来描述测试步骤，而不是使用具体的代码实现。
- 传统上一个关键字也就是一个功能方法
- 每个方法有一些固定的参数，和私有参数
- 把关键字和参数按顺序输入excel中
- 读取excel转为一个列表
- 每个元素是一个字典，包含关键字和参数
- 每个字典作为一个测试步骤
- 每个测试步骤调用对应的方法，传入参数
- 方法执行完成后，返回结果
- 结果和预期结果进行比较
- 如果一致，测试通过
- 如果不一致，测试失败